@@ -14,9 +14,9 @@ use strict;
 #
 ## Package name      : perl5
 ## Source directory  : .
-## Configuration time: Sun Mar 11 11:58:00 Local time zone must be set--see zic manual page 2007
+## Configuration time: Wed Jun 11 20:40:33 Local time zone must be set--see zic manual page 2008
 ## Configured by     : Gentoo
-## Target system     : linux beluga 2.6.19-gentoo-r6 #1 smp preempt fri feb 9 13:23:48 utc 2007 ia64 31 gnulinux 
+## Target system     : linux beluga 2.6.25-gentoo-r1 #1 smp thu may 1 16:06:07 utc 2008 ia64 31 genuineintel gnulinux 
 #
 ## Configure command line arguments.
 #PERL_PATCHLEVEL=
@@ -121,11 +121,11 @@ ccdlflags='-rdynamic'
 ccflags='-fno-strict-aliasing -pipe -Wdeclaration-after-statement -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64 -I/usr/include/gdbm'
 ccflags_uselargefiles='-D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'
 ccname='gcc'
-ccsymbols='__GNUC_MINOR__=3 __GNUC_PATCHLEVEL__=2'
+ccsymbols=''
 ccversion=''
 cf_by='Gentoo'
 cf_email='Gentoo@beluga.(none)'
-cf_time='Sun Mar 11 11:58:00 Local time zone must be set--see zic manual page 2007'
+cf_time='Wed Jun 11 20:40:33 Local time zone must be set--see zic manual page 2008'
 charsize='1'
 chgrp=''
 chmod='chmod'
@@ -146,13 +146,12 @@ config_arg18='-Dman1ext=1'
 config_arg19='-Dman3ext=3pm'
 config_arg1='-des'
 config_arg20='-Dinc_version_list=5.8.0 5.8.0/ia64-linux 5.8.2 5.8.2/ia64-linux 5.8.4 5.8.4/ia64-linux 5.8.5 5.8.5/ia64-linux 5.8.6 5.8.6/ia64-linux 5.8.7 5.8.7/ia64-linux '
-config_arg21='-Dinc_version_list=5.8.0 5.8.0/ia64-linux 5.8.2 5.8.2/ia64-linux 5.8.4 5.8.4/ia64-linux 5.8.5 5.8.5/ia64-linux 5.8.6 5.8.6/ia64-linux 5.8.7 5.8.7/ia64-linux '
-config_arg22='-Dcf_by=Gentoo'
-config_arg23='-Ud_csh'
-config_arg24='-Dusenm'
-config_arg25='-Ui_ndbm'
-config_arg26='-Ui_gdbm'
-config_arg27='-Ui_db'
+config_arg21='-Dcf_by=Gentoo'
+config_arg22='-Ud_csh'
+config_arg23='-Dusenm'
+config_arg24='-Ui_ndbm'
+config_arg25='-Ui_gdbm'
+config_arg26='-Ui_db'
 config_arg2='-Darchname=ia64-linux'
 config_arg3='-Dcccdlflags=-fPIC'
 config_arg4='-Dccdlflags=-rdynamic'
@@ -161,20 +160,20 @@ config_arg6='-Dprefix=/usr'
 config_arg7='-Dvendorprefix=/usr'
 config_arg8='-Dsiteprefix=/usr'
 config_arg9='-Dlocincpth= '
-config_argc='27'
-config_args='-des -Darchname=ia64-linux -Dcccdlflags=-fPIC -Dccdlflags=-rdynamic -Dcc=ia64-unknown-linux-gnu-gcc -Dprefix=/usr -Dvendorprefix=/usr -Dsiteprefix=/usr -Dlocincpth=  -Doptimize=-O1 -pipe -Duselargefiles -Dd_semctl_semun -Dscriptdir=/usr/bin -Dman1dir=/usr/share/man/man1 -Dman3dir=/usr/share/man/man3 -Dinstallman1dir=/usr/share/man/man1 -Dinstallman3dir=/usr/share/man/man3 -Dman1ext=1 -Dman3ext=3pm -Dinc_version_list=5.8.0 5.8.0/ia64-linux 5.8.2 5.8.2/ia64-linux 5.8.4 5.8.4/ia64-linux 5.8.5 5.8.5/ia64-linux 5.8.6 5.8.6/ia64-linux 5.8.7 5.8.7/ia64-linux  -Dinc_version_list=5.8.0 5.8.0/ia64-linux 5.8.2 5.8.2/ia64-linux 5.8.4 5.8.4/ia64-linux 5.8.5 5.8.5/ia64-linux 5.8.6 5.8.6/ia64-linux 5.8.7 5.8.7/ia64-linux  -Dcf_by=Gentoo -Ud_csh -Dusenm -Ui_ndbm -Ui_gdbm -Ui_db'
+config_argc='26'
+config_args='-des -Darchname=ia64-linux -Dcccdlflags=-fPIC -Dccdlflags=-rdynamic -Dcc=ia64-unknown-linux-gnu-gcc -Dprefix=/usr -Dvendorprefix=/usr -Dsiteprefix=/usr -Dlocincpth=  -Doptimize=-O1 -pipe -Duselargefiles -Dd_semctl_semun -Dscriptdir=/usr/bin -Dman1dir=/usr/share/man/man1 -Dman3dir=/usr/share/man/man3 -Dinstallman1dir=/usr/share/man/man1 -Dinstallman3dir=/usr/share/man/man3 -Dman1ext=1 -Dman3ext=3pm -Dinc_version_list=5.8.0 5.8.0/ia64-linux 5.8.2 5.8.2/ia64-linux 5.8.4 5.8.4/ia64-linux 5.8.5 5.8.5/ia64-linux 5.8.6 5.8.6/ia64-linux 5.8.7 5.8.7/ia64-linux  -Dcf_by=Gentoo -Ud_csh -Dusenm -Ui_ndbm -Ui_gdbm -Ui_db'
 contains='grep'
 cp='cp'
 cpio=''
 cpp='cpp'
 cpp_stuff='42'
-cppccsymbols='__GNUC__=3'
+cppccsymbols=''
 cppflags='-fno-strict-aliasing -pipe -Wdeclaration-after-statement -I/usr/include/gdbm'
 cpplast='-'
 cppminus='-'
 cpprun='ia64-unknown-linux-gnu-gcc -E'
 cppstdin='ia64-unknown-linux-gnu-gcc -E'
-cppsymbols='__ELF__=1 _FILE_OFFSET_BITS=64 __GLIBC__=2 __GLIBC_MINOR__=3 __GNUC_MINOR__=3 __GNU_LIBRARY__=6 _LARGEFILE_SOURCE=1 _LONGLONG=1 _LP64=1 __LP64__=1 _POSIX_C_SOURCE=199506L _POSIX_SOURCE=1 __STDC__=1 __USE_BSD=1 __USE_FILE_OFFSET64=1 __USE_LARGEFILE=1 __USE_MISC=1 __USE_POSIX=1 __USE_POSIX199309=1 __USE_POSIX199506=1 __USE_POSIX2=1 __USE_SVID=1 __ia64=1 __ia64__=1 linux=1 __linux=1 __linux__=1 unix=1 __unix=1 __unix__=1'
+cppsymbols='__ELF__=1 _FILE_OFFSET_BITS=64 __GLIBC__=2 __GLIBC_MINOR__=5 __GNUC__=4 __GNUC_MINOR__=1 __GNU_LIBRARY__=6 _LARGEFILE_SOURCE=1 _LONGLONG=1 _LP64=1 __LP64__=1 _POSIX_C_SOURCE=200112L _POSIX_SOURCE=1 __STDC__=1 __USE_BSD=1 __USE_FILE_OFFSET64=1 __USE_LARGEFILE=1 __USE_MISC=1 __USE_POSIX=1 __USE_POSIX199309=1 __USE_POSIX199506=1 __USE_POSIX2=1 __USE_SVID=1 __ia64=1 __ia64__=1 linux=1 __linux=1 __linux__=1 unix=1 __unix=1 __unix__=1'
 crypt_r_proto='0'
 cryptlib=''
 csh='csh'
@@ -246,7 +245,7 @@ d_dosuid='undef'
 d_drand48_r='undef'
 d_drand48proto='define'
 d_dup2='define'
-d_eaccess='undef'
+d_eaccess='define'
 d_endgrent='define'
 d_endgrent_r='undef'
 d_endhent='define'
@@ -510,7 +509,7 @@ d_sigaction='define'
 d_sigprocmask='define'
 d_sigsetjmp='define'
 d_sockatmark='define'
-d_sockatmarkproto='undef'
+d_sockatmarkproto='define'
 d_socket='define'
 d_socklen_t='define'
 d_sockpair='define'
@@ -640,7 +639,7 @@ full_csh='csh'
 full_sed='/bin/sed'
 gccansipedantic=''
 gccosandvers=''
-gccversion='3.3.2 20040119 (Gentoo Linux 3.3.2-r7, propolice-3.3-7)'
+gccversion='4.1.1 (Gentoo 4.1.1-r3)'
 getgrent_r_proto='0'
 getgrgid_r_proto='0'
 getgrnam_r_proto='0'
@@ -668,7 +667,7 @@ gidtype='gid_t'
 glibpth='/usr/shlib  /lib /usr/lib /usr/lib/386 /lib/386 /usr/ccs/lib /usr/ucblib /usr/local/lib '
 gmake='gmake'
 gmtime_r_proto='0'
-gnulibc_version='2.3.5'
+gnulibc_version='2.5'
 grep='grep'
 groupcat='cat /etc/group'
 groupstype='gid_t'
@@ -868,7 +867,7 @@ mv=''
 myarchname='ia64-linux'
 mydomain='.(none)'
 myhostname='beluga'
-myuname='linux beluga 2.6.19-gentoo-r6 #1 smp preempt fri feb 9 13:23:48 utc 2007 ia64 31 gnulinux '
+myuname='linux beluga 2.6.25-gentoo-r1 #1 smp thu may 1 16:06:07 utc 2008 ia64 31 genuineintel gnulinux '
 n='-n'
 need_va_copy='undef'
 netdb_hlen_type='size_t'
@@ -895,7 +894,7 @@ old_pthread_create_joinable=''
 optimize='-O1 -pipe'
 orderlib='false'
 osname='linux'
-osvers='2.6.19-gentoo-r6'
+osvers='2.6.25-gentoo-r1'
 otherlibdirs=' '
 package='perl5'
 pager='/usr/bin/less'
@@ -972,8 +971,8 @@ shortsize='2'
 shrpenv=''
 shsharp='true'
 sig_count='65'
-sig_name='ZERO HUP INT QUIT ILL TRAP ABRT BUS FPE KILL USR1 SEGV USR2 PIPE ALRM TERM STKFLT CHLD CONT STOP TSTP TTIN TTOU URG XCPU XFSZ VTALRM PROF WINCH IO PWR SYS NUM32 NUM33 NUM34 RTMIN NUM36 NUM37 NUM38 NUM39 NUM40 NUM41 NUM42 NUM43 NUM44 NUM45 NUM46 NUM47 NUM48 NUM49 NUM50 NUM51 NUM52 NUM53 NUM54 NUM55 NUM56 NUM57 NUM58 NUM59 NUM60 NUM61 NUM62 NUM63 RTMAX IOT CLD POLL UNUSED '
-sig_name_init='"ZERO", "HUP", "INT", "QUIT", "ILL", "TRAP", "ABRT", "BUS", "FPE", "KILL", "USR1", "SEGV", "USR2", "PIPE", "ALRM", "TERM", "STKFLT", "CHLD", "CONT", "STOP", "TSTP", "TTIN", "TTOU", "URG", "XCPU", "XFSZ", "VTALRM", "PROF", "WINCH", "IO", "PWR", "SYS", "NUM32", "NUM33", "NUM34", "RTMIN", "NUM36", "NUM37", "NUM38", "NUM39", "NUM40", "NUM41", "NUM42", "NUM43", "NUM44", "NUM45", "NUM46", "NUM47", "NUM48", "NUM49", "NUM50", "NUM51", "NUM52", "NUM53", "NUM54", "NUM55", "NUM56", "NUM57", "NUM58", "NUM59", "NUM60", "NUM61", "NUM62", "NUM63", "RTMAX", "IOT", "CLD", "POLL", "UNUSED", 0'
+sig_name='ZERO HUP INT QUIT ILL TRAP ABRT BUS FPE KILL USR1 SEGV USR2 PIPE ALRM TERM STKFLT CHLD CONT STOP TSTP TTIN TTOU URG XCPU XFSZ VTALRM PROF WINCH IO PWR SYS NUM32 NUM33 RTMIN NUM35 NUM36 NUM37 NUM38 NUM39 NUM40 NUM41 NUM42 NUM43 NUM44 NUM45 NUM46 NUM47 NUM48 NUM49 NUM50 NUM51 NUM52 NUM53 NUM54 NUM55 NUM56 NUM57 NUM58 NUM59 NUM60 NUM61 NUM62 NUM63 RTMAX IOT CLD POLL UNUSED '
+sig_name_init='"ZERO", "HUP", "INT", "QUIT", "ILL", "TRAP", "ABRT", "BUS", "FPE", "KILL", "USR1", "SEGV", "USR2", "PIPE", "ALRM", "TERM", "STKFLT", "CHLD", "CONT", "STOP", "TSTP", "TTIN", "TTOU", "URG", "XCPU", "XFSZ", "VTALRM", "PROF", "WINCH", "IO", "PWR", "SYS", "NUM32", "NUM33", "RTMIN", "NUM35", "NUM36", "NUM37", "NUM38", "NUM39", "NUM40", "NUM41", "NUM42", "NUM43", "NUM44", "NUM45", "NUM46", "NUM47", "NUM48", "NUM49", "NUM50", "NUM51", "NUM52", "NUM53", "NUM54", "NUM55", "NUM56", "NUM57", "NUM58", "NUM59", "NUM60", "NUM61", "NUM62", "NUM63", "RTMAX", "IOT", "CLD", "POLL", "UNUSED", 0'
 sig_num='0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 6 17 29 31 '
 sig_num_init='0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 6, 17, 29, 31, 0'
 sig_size='69'
